==> jc-1.4.0.tar.gz: soot/jimple/spark/fieldrw/FieldTagger.h <==
// public class soot.jimple.spark.fieldrw.FieldTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 4f60bfb16ed023ca soot_jimple_spark_fieldrw_FieldTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldTagger_H_
#define _JC_soot_jimple_spark_fieldrw_FieldTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object;
struct _jc_soot_util_HashMultiMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$refs	_jc_soot_jimple_spark_fieldrw_FieldTagger$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object	_jc_soot_jimple_spark_fieldrw_FieldTagger$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods	_jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtable	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$ensureProcessed$384f6a2d0165a993(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagger$method_info$ensureProcessed$384f6a2d0165a993;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *_jc_soot_jimple_spark_fieldrw_FieldTagger$method$v$2df928b73b820833(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods {
	void	(*ensureProcessed$384f6a2d0165a993)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_SootMethod$object *);
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods	soot_jimple_spark_fieldrw_FieldTagger;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs {
	struct _jc_java_util_HashSet$object	*processedMethods;
	struct _jc_soot_util_HashMultiMap$object	*methodToWrite;
	struct _jc_soot_util_HashMultiMap$object	*methodToRead;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$refs {
    _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs	soot_jimple_spark_fieldrw_FieldTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs	soot_jimple_spark_fieldrw_FieldTagger;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object {
	_jc_soot_jimple_spark_fieldrw_FieldTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype _jc_soot_jimple_spark_fieldrw_FieldTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldTagger$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldTagger_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/fieldrw/FieldTagger.h <==
// public class soot.jimple.spark.fieldrw.FieldTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 4f60bfb16ed023ca soot_jimple_spark_fieldrw_FieldTagger

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_spark_fieldrw_FieldTagger_H_
#define _JC_soot_jimple_spark_fieldrw_FieldTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object;
struct _jc_soot_util_HashMultiMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs	_jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$refs	_jc_soot_jimple_spark_fieldrw_FieldTagger$refs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs	_jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs;
typedef struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object	_jc_soot_jimple_spark_fieldrw_FieldTagger$object;

typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods	_jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtable	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtable;
typedef const struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtype;

// Constructors
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$ensureProcessed$384f6a2d0165a993(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_fieldrw_FieldTagger$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagger$method_info$ensureProcessed$384f6a2d0165a993;
extern _jc_method _jc_soot_jimple_spark_fieldrw_FieldTagger$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *_jc_soot_jimple_spark_fieldrw_FieldTagger$method$v$2df928b73b820833(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods {
	void	(*ensureProcessed$384f6a2d0165a993)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vmethods	soot_jimple_spark_fieldrw_FieldTagger;
};

// Vtype
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs {
	struct _jc_java_util_HashSet$object	*processedMethods;
	struct _jc_soot_util_HashMultiMap$object	*methodToWrite;
	struct _jc_soot_util_HashMultiMap$object	*methodToRead;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$refs {
    _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_refs	soot_jimple_spark_fieldrw_FieldTagger;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_spark_fieldrw_FieldTagger$sub_nonrefs	soot_jimple_spark_fieldrw_FieldTagger;
};

// Object instance structure
struct _jc_soot_jimple_spark_fieldrw_FieldTagger$object {
	_jc_soot_jimple_spark_fieldrw_FieldTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$vtype	*vtype;
	_jc_soot_jimple_spark_fieldrw_FieldTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_fieldrw_FieldTagger$vtype _jc_soot_jimple_spark_fieldrw_FieldTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_fieldrw_FieldTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_fieldrw_FieldTagger$class_object;

#endif	/* _JC_soot_jimple_spark_fieldrw_FieldTagger_H_ */
